summaryrefslogtreecommitdiff
path: root/kconfiglib.py
diff options
context:
space:
mode:
Diffstat (limited to 'kconfiglib.py')
-rw-r--r--kconfiglib.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/kconfiglib.py b/kconfiglib.py
index 29b02ad..c7fc93f 100644
--- a/kconfiglib.py
+++ b/kconfiglib.py
@@ -12,7 +12,7 @@
#
# $ make scriptconfig SCRIPT=Kconfiglib/examples/print_tree.py
#
# Look in kconfigtest.py for the test suite.
"""
Kconfiglib is a Python library for scripting and extracting information from
@@ -57,7 +57,7 @@ Look in the examples/ subdirectory for examples, which can be run with e.g.
$ make scriptconfig SCRIPT=Kconfiglib/examples/print_tree.py
-Look in kconfigtest.py for the test suite.
+Look in testsuite.py for the test suite.
Credits: Written by Ulf "Ulfalizer" Magnusson
@@ -12,7 +12,7 @@
# $ make scriptconfig SCRIPT=Kconfiglib/examples/print_tree.py
#
-# Look in kconfigtest.py for the test suite.
+# Look in testsuite.py for the test suite.
"""
Kconfiglib is a Python library for scripting and extracting information from